@@ -16,7 +16,7 @@
 ;;; 		       								 
 ;;;  You should have received a copy of the GNU General Public License		 
 ;;;  along with this program; if not, write to the Free Software 		 
-;;;  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.	 
+;;;  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 ;;;										 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -24,46 +24,40 @@
 
 (macsyma-module cgb-maxima)
 
-(eval-when
-    #+gcl (load eval)
-    #-gcl (:load-toplevel :execute)
-    (format t "~&Loading maxima-grobner ~a ~a~%"
-	    "$Revision: 1.6 $" "$Date: 2009-06-02 07:49:49 $"))
-
 ;; Macros for making lists with iterators - an exammple of GENSYM
-;; MAKELIST-1 makes a list with one iterator, while MAKELIST accepts an
+;; GROBNER-MAKELIST-1 makes a list with one iterator, while GROBNER-MAKELIST accepts an
 ;; arbitrary number of iterators
 
 ;; Sample usage:
 ;; Without a step:
-;; >(makelist-1 (* 2 i) i 0 10)
+;; >(grobner-makelist-1 (* 2 i) i 0 10)
 ;; (0 2 4 6 8 10 12 14 16 18 20)
 ;; With a step of 3:
-;; >(makelist-1 (* 2 i) i 0 10 3)
+;; >(grobner-makelist-1 (* 2 i) i 0 10 3)
 ;; (0 6 12 18)
 
 ;; Generate sums of squares of numbers between 1 and 4:
-;; >(makelist (+ (* i i) (* j j)) (i 1 4) (j 1 i))
+;; >(grobner-makelist (+ (* i i) (* j j)) (i 1 4) (j 1 i))
 ;; (2 5 8 10 13 18 17 20 25 32)
-;; >(makelist (list i j '---> (+ (* i i) (* j j))) (i 1 4) (j 1 i))
+;; >(grobner-makelist (list i j '---> (+ (* i i) (* j j))) (i 1 4) (j 1 i))
 ;; ((1 1 ---> 2) (2 1 ---> 5) (2 2 ---> 8) (3 1 ---> 10) (3 2 ---> 13)
 ;; (3 3 ---> 18) (4 1 ---> 17) (4 2 ---> 20) (4 3 ---> 25) (4 4 ---> 32))
 
 ;; Evaluate expression expr with variable set to lo, lo+1,... ,hi
 ;; and put the results in a list.
-(defmacro makelist-1 (expr var lo hi &optional (step 1))
+(defmacro grobner-makelist-1 (expr var lo hi &optional (step 1))
   (let ((l (gensym)))
     `(do ((,var ,lo (+ ,var ,step))
 	  (,l nil (cons ,expr ,l)))
 	 ((> ,var ,hi) (reverse ,l))
        (declare (fixnum ,var)))))
 
-(defmacro makelist (expr (var lo hi &optional (step 1)) &rest more)
+(defmacro grobner-makelist (expr (var lo hi &optional (step 1)) &rest more)
   (if (endp more)
-      `(makelist-1 ,expr ,var ,lo ,hi ,step)
+      `(grobner-makelist-1 ,expr ,var ,lo ,hi ,step)
     (let* ((l (gensym)))
       `(do ((,var ,lo (+ ,var ,step))
-	    (,l nil (nconc ,l `,(makelist ,expr ,@more))))
+	    (,l nil (nconc ,l `,(grobner-makelist ,expr ,@more))))
 	   ((> ,var ,hi) ,l)
 	 (declare (fixnum ,var))))))
 
@@ -94,8 +88,6 @@
   "Type of monomial."
   `(simple-array exponent (,dim)))
 
-(declaim (optimize (speed 3) (safety 1)))
-
 (declaim (ftype (function (monom) fixnum) monom-dimension monom-sugar)
 	 (ftype (function (monom &optional fixnum fixnum) fixnum) monom-total-degree)
 	 (ftype (function (monom monom) monom) monom-div monom-mul monom-lcm monom-gcd)
@@ -107,10 +99,6 @@
 	 ;;(ftype (function (monom monom) monom) monom-append)
 	 )
 
-(declaim (inline monom-mul monom-div
-		 monom-total-degree monom-divides-p
-		 monom-divisible-by-p monom-rel-prime monom-lcm))
-
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
 ;; Construction of monomials
@@ -145,13 +133,13 @@ specifies the common power for all variables."
   (length m))
 
 (defun monom-total-degree (m &optional (start 0) (end (length m)))
-  "Return the todal degree of a monomoal M. Optinally, a range
+  "Return the todal degree of a monomoal M. Optionally, a range
 of variables may be specified with arguments START and END."
   (declare (type monom m) (fixnum start end))
   (reduce #'+ m :start start :end end))
 
 (defun monom-sugar (m &aux (start 0) (end (length m)))
-  "Return the sugar of a monomial M. Optinally, a range
+  "Return the sugar of a monomial M. Optionally, a range
 of variables may be specified with arguments START and END."
   (declare (type monom m) (fixnum start end))
   (monom-total-degree m start end))
@@ -546,7 +534,6 @@ Top reduction means that division algorithm stops after the first reduction.")
 
 (defstruct (term
 	    (:constructor make-term (monom coeff))
-	    (:constructor make-term-variable)
 	    ;;(:type list)
 	    )
   (monom (make-monom 0) :type monom)
@@ -601,7 +588,7 @@ even if there are divisors of 0."
 (declaim (ftype (function (ring term term) list) term-mul))
 
 (defun term-mul (ring term1 term2)
-  "Returns (LIST TERM) wheter TERM is the product of the terms TERM1 TERM2,
+  "Returns (LIST TERM) whether TERM is the product of the terms TERM1 TERM2,
 or NIL when the product is 0. This definition takes care of divisors of 0
 in the coefficient ring."
   (let ((c (funcall (ring-mul ring) (term-coeff term1) (term-coeff term2))))
@@ -859,15 +846,13 @@ at the beginning of each monomial."
   (make-poly-from-termlist (termlist-contract (poly-termlist p) k)
 	     (poly-sugar p)))
 
-(declaim (ftype (function (poly &optional sequence)) poly-extend))
+(declaim (ftype (function (poly &optional sequence) poly) poly-extend))
 
 (defun poly-extend (p &optional (m (make-monom 1 :initial-element 0)))
   (make-poly-from-termlist
    (termlist-extend (poly-termlist p) m)
    (+ (poly-sugar p) (monom-sugar m))))
 
-(declaim (ftype (function (poly fixnum)) poly-add-variables))
-
 (defun poly-add-variables (p k)
   (setf (poly-termlist p) (termlist-add-variables (poly-termlist p) k))
   p)
@@ -964,26 +949,6 @@ at the beginning of each monomial."
 	(otherwise
 	 (coerce-coeff ring expr vars)))))))
 
-
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;
-;; Global optimization/debugging options
-;;
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-
-
-;;All inline functions of this module
-(declaim (inline free-of-vars make-pair-queue pair-queue-insert
-		 pair-queue-remove pair-queue-empty-p
-		 pair-queue-remove pair-queue-size criterion-1
-		 criterion-2 grobner reduced-grobner sugar-pair-key
-		 sugar-order normal-form normal-form-step grobner-op spoly
-		 equal-test-p
-		 ))
-
-;;Optimization options
-(declaim (optimize (speed 3) (safety 1)))
-
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
@@ -1189,7 +1154,7 @@ criterion: for every two polynomials h1 and h2 in G the S-polynomial
 S(h1,h2) reduces to 0 modulo G."
   (every
    #'poly-zerop
-   (makelist (normal-form ring (spoly ring (elt g i) (elt g j)) g nil)
+   (grobner-makelist (normal-form ring (spoly ring (elt g i) (elt g j)) g nil)
 	     (i 0 (- (length g) 2))
 	     (j (1+ i) (1- (length g))))))
 
@@ -1201,7 +1166,7 @@ upon success and NIL otherwise."
 	(stat1 (buchberger-criterion ring g))
 	(stat2
 	  (every #'poly-zerop
-		 (makelist (normal-form ring (copy-tree (elt f i)) g nil)
+		 (grobner-makelist (normal-form ring (copy-tree (elt f i)) g nil)
 			   (i 0 (1- (length f)))))))
     (unless stat1 (error "~&Buchberger criterion failed."))
     (unless stat2
@@ -1264,9 +1229,9 @@ in the pair queue.")
 (defun pair-queue-initialize (pq f start
 			      &aux
 			      (s (1- (length f)))
-			      (b (nconc (makelist (make-pair (elt f i) (elt f j))
+			      (b (nconc (grobner-makelist (make-pair (elt f i) (elt f j))
 						 (i 0 (1- start)) (j start s))
-					(makelist (make-pair (elt f i) (elt f j))
+					(grobner-makelist (make-pair (elt f i) (elt f j))
 						 (i start (1- s)) (j (1+ i) s)))))
   "Initializes the priority for critical pairs. F is the initial list of polynomials.
 START is the first position beyond the elements which form a partial
@@ -1298,7 +1263,7 @@ grobner basis, i.e. satisfy the Buchberger criterion."
 of the ideal generated by the polynomial list F.  Polynomials 0 to
 START-1 are assumed to be a Grobner basis already, so that certain
 critical pairs will not be examined. If TOP-REDUCTION-ONLY set, top
-reduction will be preformed. This function assumes that all polynomials
+reduction will be performed. This function assumes that all polynomials
 in F are non-zero."
   (declare (type fixnum start))
   (when (endp f) (return-from buchberger f)) ;cut startup costs
@@ -1349,7 +1314,7 @@ in F are non-zero."
 of the ideal generated by the polynomial list F.  Polynomials 0 to
 START-1 are assumed to be a Grobner basis already, so that certain
 critical pairs will not be examined. If TOP-REDUCTION-ONLY set, top
-reduction will be preformed."
+reduction will be performed."
   (declare (ignore top-reduction-only)
 	   (type fixnum start))
   (when (endp f) (return-from parallel-buchberger f)) ;cut startup costs
@@ -1532,7 +1497,7 @@ that all polynomials in F are non-zero."
 		 c d e
 		 (b-new (make-pair-queue))
 		 g-new)
-  "An implementation of the auxillary UPDATE algorithm used by the
+  "An implementation of the auxiliary UPDATE algorithm used by the
 Gebauer-Moeller algorithm. G is a list of polynomials, B is a list of
 critical pairs and H is a new polynomial which possibly will be added
 to G. The naming conventions used are very close to the one used in
@@ -2177,7 +2142,7 @@ are assumed to be defined.")
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;; Auxillary function for removing zero polynomial
+;; Auxiliary function for removing zero polynomial
 (defun remzero (plist) (remove #'poly-zerop plist))
 
 ;;Simple operators
