@@ -1,6 +1,6 @@
 ;;; -*-  Mode: Lisp; Package: Maxima; Syntax: Common-Lisp; Base: 10 -*- ;;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;     The data in this file contains enhancments.                    ;;;;;
+;;;     The data in this file contains enhancements.                   ;;;;;
 ;;;                                                                    ;;;;;
 ;;;  Copyright (c) 1984,1987 by William Schelter,University of Texas   ;;;;;
 ;;;     All rights reserved                                            ;;;;;
@@ -16,9 +16,6 @@
 ;;                        MMACROEXPANDED, MMACROEXPAND and MMACROEXPAND1
 
 
-(declare-top (special $macros $functions $transrun $translate))
-
- 
 ;; $MACROS declared in jpg;mlisp >
 
 
@@ -32,7 +29,7 @@ means to completely replace the form with the expansion.  This is more space
 efficient than EXPAND but grinds and displays the expansion instead of the
 call."
   modified-commands '($macroexpand)
-  setting-list      '( () $expand $displace ) )
+  :setting-list      (() $expand $displace))
 
 
 ;;; LOCAL MACRO ;;;
@@ -61,6 +58,9 @@ call."
 	  ((not (eq name (caar fun)))	;efficiency hack I guess
 	   (rplaca (car fun) name)))	;  done in jpg;mlisp
     (setq args (cdr fun))		;  (in MDEFINE).
+    (let ((dup (find-duplicate args :test #'eq :key #'mparam)))
+      (when dup
+        (merror (intl:gettext "macro definition: ~M occurs more than once in the parameter list") (mparam dup))))
     (mredef-check name)
     (do ((a args (cdr a)) (mlexprp))
 	((null a)
@@ -88,7 +88,7 @@ call."
 ;;; EVALUATING A MACRO CALL ;;;
 
 
-(defmfun mmacro-apply (defn form)
+(defun mmacro-apply (defn form)
   (mmacroexpansion-check form
 			 (if (and (atom defn)
 				  (not (symbolp defn)))
@@ -193,8 +193,8 @@ call."
 (defprop mdefmacro simpmdefmacro operators)
 
 ;; emulating simpmdef (for mdefine) in jm;simp
-(defmfun simpmdefmacro (x *ignored* simp-flag)
-  (declare (ignore *ignored* simp-flag))
+(defun simpmdefmacro (x ignored simp-flag)
+  (declare (ignore ignored simp-flag))
   (cons '(mdefmacro simp) (cdr x)))
 
 (defun displace (x y)
